==> dde-shell_1.0.10.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation>Estil de l&apos;indicador</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation>Alineació</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation>Alinea a l&apos;esquerra</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation>Alinea a dalt</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation>Alinea el centre</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Mantén-ho visible</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Mantén-ho amagat</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Paràmetres de l&apos;acoblador</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estil de l&apos;indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Mode de moda</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mode eficient</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Mode clàssic</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Mode centrat</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>A l&apos;esquerra</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>A la dreta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mantén-ho visible</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mantén-ho amagat</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultació intel·ligent</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Paràmetres de l&apos;acoblador</translation>
    </message>
</context>
</TS>
